#ifndef QRK_AUDIO_H
#define QRK_AUDIO_H

/*!
  \file
  \brief Audio の初期化

  \author Satofumi KAMIMURA

  $Id: Audio.h 684 2009-03-29 00:50:32Z satofumi $
*/

namespace qrk
{
  class Audio
  {
    Audio(const Audio& rhs);
    Audio& operator = (const Audio& rhs);

    struct pImpl;
    pImpl* pimpl;

  public:
    Audio(void);
    ~Audio(void);

    const char* what(void) const;

    bool initialize(void);
    bool isInitialized(void);
  };
}

#endif /* !QRK_AUDIO_H */
